@@ -20,7 +20,7 @@ class CompileMo(object):
                 if ext == '.po':
                     po = open(os.path.join(dirpath, filename))
                     mo = file(os.path.join(dirpath, domain + '.mo'), 'wb')
-                    logging.getLogger(self.name).info(
+                    logging.getLogger(self.name).debug(
                         "compiling catalog '%s' to '%s'"%(po.name, mo.name))
                     write_mo(mo, read_po(po))
                     generated.append(mo.name)
